Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(865)

Unified Diff: Source/core/frame/LocalDOMWindow.h

Issue 1026253002: Rename FrameDestructionObserver to LocalFrameLifecycleObserver. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: rebased Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/frame/FrameDestructionObserver.h ('k') | Source/core/frame/LocalDOMWindow.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/frame/LocalDOMWindow.h
diff --git a/Source/core/frame/LocalDOMWindow.h b/Source/core/frame/LocalDOMWindow.h
index 71a8aaab2fbf7cdad68d1b715e093bc3f2688386..ec0a255e3c65cbc3f7a2376c0bc2d8d1010996d5 100644
--- a/Source/core/frame/LocalDOMWindow.h
+++ b/Source/core/frame/LocalDOMWindow.h
@@ -32,8 +32,8 @@
#include "core/frame/DOMWindow.h"
#include "core/frame/DOMWindowLifecycleNotifier.h"
#include "core/frame/DOMWindowLifecycleObserver.h"
-#include "core/frame/FrameDestructionObserver.h"
#include "core/frame/LocalFrame.h"
+#include "core/frame/LocalFrameLifecycleObserver.h"
#include "platform/Supplementable.h"
#include "platform/heap/Handle.h"
@@ -213,13 +213,13 @@ public:
virtual v8::Handle<v8::Object> wrap(v8::Handle<v8::Object> creationContext, v8::Isolate*) override;
private:
// Rather than simply inheriting FrameDestructionObserver like most other
// classes, LocalDOMWindow hides its FrameDestructionObserver with
// composition. This prevents conflicting overloads between DOMWindow, which
// has a frame() accessor that returns Frame* for bindings code, and
// FrameDestructionObserver, which has a frame() accessor that returns a
// LocalFrame*.
- class WindowFrameObserver final : public NoBaseWillBeGarbageCollected<WindowFrameObserver>, public FrameDestructionObserver {
+ class WindowFrameObserver final : public NoBaseWillBeGarbageCollected<WindowFrameObserver>, public LocalFrameLifecycleObserver {
WTF_MAKE_FAST_ALLOCATED_WILL_BE_REMOVED(WindowFrameObserver);
WILL_BE_USING_GARBAGE_COLLECTED_MIXIN(WindowFrameObserver);
DECLARE_EMPTY_VIRTUAL_DESTRUCTOR_WILL_BE_REMOVED(WindowFrameObserver);
@@ -231,7 +231,7 @@ private:
private:
WindowFrameObserver(LocalDOMWindow*, LocalFrame&);
- // FrameDestructionObserver overrides:
+ // LocalFrameLifecycleObserver overrides:
void willDetachFrameHost() override;
void contextDestroyed() override;
« no previous file with comments | « Source/core/frame/FrameDestructionObserver.h ('k') | Source/core/frame/LocalDOMWindow.cpp » ('j') | no next file with comments »
@@ -213,13 +213,13 @@ public:
virtual v8::Handle<v8::Object> wrap(v8::Handle<v8::Object> creationContext, v8::Isolate*) override;
private:
- // Rather than simply inheriting FrameDestructionObserver like most other
- // classes, LocalDOMWindow hides its FrameDestructionObserver with
+ // Rather than simply inheriting LocalFrameLifecycleObserver like most other
+ // classes, LocalDOMWindow hides its LocalFrameLifecycleObserver with
// composition. This prevents conflicting overloads between DOMWindow, which
// has a frame() accessor that returns Frame* for bindings code, and
@@ -213,13 +213,13 @@ public:
// composition. This prevents conflicting overloads between DOMWindow, which
// has a frame() accessor that returns Frame* for bindings code, and
- // FrameDestructionObserver, which has a frame() accessor that returns a
+ // LocalFrameLifecycleObserver, which has a frame() accessor that returns a
// LocalFrame*.

Powered by Google App Engine
This is Rietveld 408576698